@@ -43,8 +43,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
-                  dataroot = "./data/",
+                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
+#                  dataroot = "./data/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
@@ -84,6 +84,8 @@ print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_
 num_layers = len(list(model.parameters()))
 print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
 
+#print(list(model.parameters()))
+
 dls.show_network_summary(model)
 
 detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model)
